@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022 Valory AG
+#   Copyright 2022-2023 Valory AG
 #   Copyright 2018-2019 Fetch.AI Limited
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,16 +21,18 @@
 
 from typing import Any, Dict, Optional
 
-from aea_ledger_fetchai._cosmos import (
+from aea_ledger_cosmos.cosmos import (
     CosmosCrypto,
     CosmosFaucetApi,
     CosmosHelper,
+    MAXIMUM_GAS_AMOUNT,
     _CosmosApi,
 )
 
 from aea.common import JSONLike
 
 
+_ = MAXIMUM_GAS_AMOUNT
 _FETCHAI = "fetchai"
 _FETCH = "fetch"
 TESTNET_NAME = "testnet"
@@ -80,7 +82,7 @@ class FetchAIApi(_CosmosApi, FetchAIHelper):
         :param method_name: the contract method to call
         :param method_args: the contract call parameters
         """
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: nocover
 
     def build_transaction(
         self,
@@ -98,7 +100,7 @@ class FetchAIApi(_CosmosApi, FetchAIHelper):
         :param tx_args: the transaction parameters
         :param raise_on_try: whether the method will raise or log on error
         """
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: nocover
 
     def get_transaction_transfer_logs(
         self,
@@ -113,7 +115,7 @@ class FetchAIApi(_CosmosApi, FetchAIHelper):
         :param tx_hash: the transaction hash
         :param target_address: optional address to filter transfer events to just those that affect it
         """
-        raise NotImplementedError
+        raise NotImplementedError  # pragma: nocover
 
 
 class FetchAIFaucetApi(CosmosFaucetApi):
